==> haskell-prelude-extras-0.4.0.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prelude-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prelude-extras
version:              0.4.0.3
visibility:           public
id:                   prelude-extras-0.4.0.3-FbgjpWtjMD5HIWXb8zbCUn
key:                  prelude-extras-0.4.0.3-FbgjpWtjMD5HIWXb8zbCUn
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/prelude-extras
synopsis:             Higher order versions of Prelude classes
description:
    Higher order versions of Prelude classes to ease programming with polymorphic recursion and reduce UndecidableInstances

    See <http://flint.cs.yale.edu/trifonov/papers/sqcc.pdf> for further discussion of the approach taken here.

category:             Polymorphism, Combinators
abi:                  5122e0c63c8b6eb2361aca1880ffa539
exposed:              True
exposed-modules:      Prelude.Extras
import-dirs:          /usr/lib/ghc-8.10.1/site-local/prelude-extras-0.4.0.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/prelude-extras-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/prelude-extras-0.4.0.3
hs-libraries:         HSprelude-extras-0.4.0.3-FbgjpWtjMD5HIWXb8zbCUn
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-prelude-extras/html/prelude-extras.haddock

haddock-html:         /usr/share/doc/haskell-prelude-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prelude-extras-0.4.0.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prelude-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prelude-extras
version:              0.4.0.3
visibility:           public
id:                   prelude-extras-0.4.0.3-4lYyNWth6ZB18sidzBxFSH
key:                  prelude-extras-0.4.0.3-4lYyNWth6ZB18sidzBxFSH
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/prelude-extras
synopsis:             Higher order versions of Prelude classes
description:
    Higher order versions of Prelude classes to ease programming with polymorphic recursion and reduce UndecidableInstances

    See <http://flint.cs.yale.edu/trifonov/papers/sqcc.pdf> for further discussion of the approach taken here.

category:             Polymorphism, Combinators
abi:                  37025e4002591fa54e21fb6d600da021
exposed:              True
exposed-modules:      Prelude.Extras
import-dirs:          /usr/lib/ghc-8.10.2/site-local/prelude-extras-0.4.0.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/prelude-extras-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/prelude-extras-0.4.0.3
hs-libraries:         HSprelude-extras-0.4.0.3-4lYyNWth6ZB18sidzBxFSH
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-prelude-extras/html/prelude-extras.haddock

haddock-html:         /usr/share/doc/haskell-prelude-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
